# DreamNet
DreamNet is a simple text-based toy that lets you interact with nodes on [ConceptNet](http://conceptnet.io). 

Call dreamnet.main() after installing to begin. You will be presented with a scene populated by a few objects. You can type the name of any object in the scene to interact with it, and type 'dream' to visit a new scene. Interacting with objects will create new items to interact with, ad infinium. Have fun and sleep tight!